# TOPPY - Graphical system rsources monitor in python

Toppy is a graphical system resource monitor that uses matplotlib for plotting.

Currently, displays 5 graphs:
- CPU utilization
- GPU utilization
- Memory usage
- Device IO
- Network IO

## Installation

`pip install toppy`

## Execution

`python -m toppy`
